==> ka-table-1.0.8.tgz: package/Utils/EventUtils.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
import { Events } from '../enums';
import { getCopyOfArrayAndInsertOrReplaceItem } from './ArrayUtils';
import { changeCellEditorToCellTextHandler, changeCellTextToCellEditorHandler } from './CellUtils';
import { getSortedColumns } from './HeadRowUtils';
export var getOnEventHandler = function (_a) {
    var columns = _a.columns, data = _a.data, _b = _a.editableCells, editableCells = _b === void 0 ? [] : _b, _c = _a.onDataChange, onDataChange = _c === void 0 ? function () { } : _c, _d = _a.onEvent, onEvent = _d === void 0 ? function () { } : _d, onOptionChange = _a.onOptionChange, rowKeyField = _a.rowKeyField, _e = _a.selectedRows, selectedRows = _e === void 0 ? [] : _e, virtualScrolling = _a.virtualScrolling;
    return function (event, eventData) {
        switch (event) {
            case Events.OpenEditor:
                changeCellTextToCellEditorHandler(eventData.cell, editableCells, onOptionChange);
                break;
            case Events.CloseEditor:
                changeCellEditorToCellTextHandler(eventData.cell, editableCells, onOptionChange);
                break;
            case Events.RowDataChanged:
                var newData = getCopyOfArrayAndInsertOrReplaceItem(eventData, rowKeyField, data);
                onDataChange(newData);
                break;
            case Events.RowSelected:
                onOptionChange({ selectedRows: __spreadArrays(selectedRows, [eventData.rowKeyValue]) });
                break;
            case Events.RowDeselected:
                onOptionChange({ selectedRows: __spreadArrays(selectedRows).filter(function (s) { return s !== eventData.rowKeyValue; }) });
                break;
            case Events.SortingChanged:
                var sortedColumns = getSortedColumns(columns, eventData.column);
                onOptionChange({ columns: sortedColumns });
                break;
            case Events.ScrollTable:
                if (virtualScrolling) {
                    var scrollPosition = eventData.scrollTop;
                    if (virtualScrolling) {
                        onOptionChange({ virtualScrolling: __assign(__assign({}, virtualScrolling), { scrollPosition: scrollPosition }) });
                    }
                }
                break;
        }
        onEvent(event, eventData);
    };
};

==> ka-table-1.2.2.tgz: package/Utils/EventUtils.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
import { Events } from '../enums';
import { getCopyOfArrayAndInsertOrReplaceItem } from './ArrayUtils';
import { changeCellEditorToCellTextHandler, changeCellTextToCellEditorHandler } from './CellUtils';
import { getSortedColumns } from './HeadRowUtils';
export var getOnEventHandler = function (_a) {
    var columns = _a.columns, data = _a.data, _b = _a.editableCells, editableCells = _b === void 0 ? [] : _b, _c = _a.onDataChange, onDataChange = _c === void 0 ? function () { } : _c, _d = _a.onEvent, onEvent = _d === void 0 ? function () { } : _d, onOptionChange = _a.onOptionChange, rowKeyField = _a.rowKeyField, _e = _a.selectedRows, selectedRows = _e === void 0 ? [] : _e, virtualScrolling = _a.virtualScrolling;
    return function (event, eventData) {
        switch (event) {
            case Events.OpenEditor:
                changeCellTextToCellEditorHandler(eventData.cell, editableCells, onOptionChange);
                break;
            case Events.CloseEditor:
                changeCellEditorToCellTextHandler(eventData.cell, editableCells, onOptionChange);
                break;
            case Events.RowDataChanged:
                var newData = getCopyOfArrayAndInsertOrReplaceItem(eventData.newValue, rowKeyField, data);
                onDataChange(newData);
                break;
            case Events.RowSelected:
                onOptionChange({ selectedRows: __spreadArrays(selectedRows, [eventData.rowKeyValue]) });
                break;
            case Events.RowDeselected:
                onOptionChange({ selectedRows: __spreadArrays(selectedRows).filter(function (s) { return s !== eventData.rowKeyValue; }) });
                break;
            case Events.SortingChanged:
                var sortedColumns = getSortedColumns(columns, eventData.column);
                onOptionChange({ columns: sortedColumns });
                break;
            case Events.ScrollTable:
                if (virtualScrolling) {
                    var scrollPosition = eventData.scrollTop;
                    if (virtualScrolling) {
                        onOptionChange({ virtualScrolling: __assign(__assign({}, virtualScrolling), { scrollPosition: scrollPosition }) });
                    }
                }
                break;
        }
        onEvent(event, eventData);
    };
};
